# Wheel names will be generated according to this value. Do not manually modify this value; instead
# update it according to committed changes by running this command from the root of the repository:
#
#   uv run python -m AutoGitSemVer.scripts.UpdatePythonVersion ./src/uvrepotemplate/__init__.py ./src
#
__version__ = "0.1.4"

# BugBug: Testing! 4


def Add(
    a: int,
    b: int,
) -> int:
    return a + b


def Subtract(
    a: int,
    b: int,
) -> int:
    return a - b



import uvrepotemplate


def test_Add1():
    assert uvrepotemplate.Add(1, 12) == 13


def test_Add2():
    assert uvrepotemplate.Add(1, 12) == 13


def test_Subtract():
    assert uvrepotemplate.Subtract(1, 10) == -9
